<template>
	<div>
		<el-form :disabled="hadSubmit" :model="dialogFormValue" ref="dialogFormRef" :rules="dialogFormRules" label-width="86">
			<el-form-item label="工单编号" prop="id" disabled>
				<el-input v-model="dialogFormValue.id" readonly></el-input>
			</el-form-item>
			<el-form-item label="工单名称" prop="title">
				<el-input v-model="dialogFormValue.title"></el-input>
			</el-form-item>
			<el-form-item label="工单类型" prop="type">
				<el-select v-model="dialogFormValue.type">
					<el-option
						v-for="item in [
							{ ID: '设备维修', Name: '设备维修' },
							{ ID: '流量异常', Name: '流量异常' },
							{ ID: '压力异常', Name: '压力异常' },
							{ ID: '水质异常', Name: '水质异常' },
							{ ID: '用户投诉', Name: '用户投诉' },
						]"
						:key="item.ID"
						:value="item.ID"
						:label="item.Name"
					></el-option>
				</el-select>
			</el-form-item>
			<el-form-item label="工单内容" prop="content">
				<el-input v-model="dialogFormValue.content" type="textarea" :rows="3"></el-input>
			</el-form-item>
			<!-- <el-form-item label="上报人" prop="question">
				<el-select v-model="dialogFormValue.prompt">
					<el-option
						v-for="item in [
							{ ID: '1', Name: '张三' },
							{ ID: '2', Name: '李四' },
						]"
						:key="item.ID"
						:value="item.ID"
						:label="item.Name"
					></el-option>
				</el-select>
			</el-form-item> -->

			<el-form-item label="备注" prop="remark">
				<el-input v-model="dialogFormValue.remark" type="textarea" :rows="3"></el-input>
			</el-form-item>
			<el-form-item label="附件图片" prop="pic">
				<el-upload
					v-model:file-list="dialogFormValue.pic"
					ref="uploadRef"
					action="#"
					list-type="picture-card"
					:auto-upload="true"
					:http-request="uploadRequest"
					:on-success="handleUploadSuccess"
				>
					<el-icon><Plus /></el-icon>

					<template #file="{ file }">
						<div>
							<img class="el-upload-list__item-thumbnail" :src="file.url" alt="" />
							<span class="el-upload-list__item-actions">
								<span class="el-upload-list__item-preview" @click="handlePictureCardPreview(file)">
									<el-icon><zoom-in /></el-icon>
								</span>
								<!-- <span v-if="!disabled" class="el-upload-list__item-delete" @click="handleDownload(file)">
								<el-icon><Download /></el-icon>
							</span> -->
								<span class="el-upload-list__item-delete" @click="handleRemove(file)">
									<el-icon><Delete /></el-icon>
								</span>
							</span>
						</div>
					</template>
				</el-upload>
			</el-form-item>

			<el-form-item>
				<el-button class="ml-auto" type="primary" @click="handleSubmit" :loading="submitting"> 提交工单 </el-button>
			</el-form-item>
		</el-form>
		<el-dialog v-model="dialogVisible">
			<img w-full :src="dialogImageUrl" alt="Preview Image" />
		</el-dialog>
	</div>
</template>

<script setup lang="ts" name="CreateWorkOrder">
import { toFormData } from 'axios';
import type { UploadFile, UploadRawFile } from 'element-plus';
import { ElMessage, ElMessageBox, ElUpload, type FormRules, type UploadRequestOptions } from 'element-plus';
import type { PropType } from 'vue';
import { onMounted, ref } from 'vue';
import type { ModeContent } from '../model/types';
import { formatDate } from '/@/utils/formatTime';
import { useCompRef } from '/@/utils/types';
const props = defineProps({
	data: {
		type: Object as PropType<ModeContent>,
		default: () => {},
	},
});

const dialogFormValue = ref<any>({
	id: `GM_${formatDate(new Date(), 'YYYY_mmdd_HHMMSS')}`,
	title: '',
	type: '',
	content: '',
	remark: '',
	pic: [],
});
const dialogFormRules = ref<FormRules>({
	// title: [{ required: true, message: '请输入标题', trigger: 'blur' }],
	// prompt: [{ required: true, message: '请输入提示词', trigger: 'blur' }],
});
const uploadRequest = (options: UploadRequestOptions) => {
	const { name, size } = options.file;
	const formData = toFormData({});
	formData.append('file', options.file);
};

const handleUploadSuccess = (value) => {};
const dialogImageUrl = ref('');
const dialogVisible = ref(false);
const handlePictureCardPreview = (file: UploadFile) => {
	dialogImageUrl.value = file.url!;
	dialogVisible.value = true;
};
const uploadRef = useCompRef(ElUpload);

const removeFile = (file: UploadFile | UploadRawFile) => {
	// if (type === ImageCatagoryEnum.Background) {
	// 	bgUploadRef.value?.uploadRef?.handleRemove(file);
	// } else if (type === ImageCatagoryEnum.Element) {
	// 	eleUploadRef.value?.uploadRef?.handleRemove(file);
	// } else if (type === ImageCatagoryEnum.ImgTranslator) {
	// 	imgTranslatorRef.value?.uploadRef?.handleRemove(file);
	// }
	uploadRef.value?.handleRemove(file);
};
const handleRemove = (file: UploadFile) => {
	ElMessageBox.confirm(`确定删除当前图片：【${file.name}】?`, '提示', {
		confirmButtonText: '确定',
		cancelButtonText: '取消',
		type: 'warning',
	}).then(async () => {
		removeFile(file);
		// 删除文件记录
		// const res = await bankImageApi.DeleteArtImageBankImageByID({
		// 	ID: (file as any).id,
		// });
		// if (res?.Code === 0) {
		// 	if (res.Data) {
		// 		removeFile(file, type);
		// 		ElMessage.success('删除图片成功');
		// 	} else {
		// 		ElMessage.error('删除图片失败');
		// 	}
		// } else {
		// 	ElMessage.error('删除图片失败' + (res?.Message ? `，${JSON.stringify(res.Message)}` : ''));
		// }
	});
};

const dialogFormRef = ref();
const submitting = ref(false);

const hadSubmit = ref(false);

const handleSubmit = async () => {
	if (!dialogFormRef.value) return;

	try {
		submitting.value = true;
		await dialogFormRef.value.validate();

		// TODO: 这里添加提交工单的 API 调用
		// const res = await submitWorkOrder(dialogFormValue.value);

		ElMessage.success('工单提交成功');
		hadSubmit.value = true;
		// 清空表单
		// dialogFormRef.value.resetFields();
		// uploadRef.value?.clearFiles();
	} catch (error: any) {
		if (error?.message) {
			ElMessage.error(error.message);
		}
	} finally {
		submitting.value = false;
	}
};

onMounted(() => {
	if (props.data?.value) {
		const formValue = JSON.parse(props.data.value);
		dialogFormValue.value = {
			...dialogFormValue.value,
			...formValue,
		};
	}
});
</script>
<style scoped lang="scss"></style>
